@@ -104,10 +104,10 @@ static int rtl8168_eeprom_cmd_done(struct rtl8168_private *tp)
                 x = RTL_R8(tp, Cfg9346);
 
                 if (x & Cfg9346_EEDO) {
-                        udelay(RTL_CLOCK_RATE * 2 * 3);
+                        fsleep(RTL_CLOCK_RATE * 2 * 3);
                         return 0;
                 }
-                udelay(1);
+                fsleep(1);
         }
 
         return -1;
@@ -199,7 +199,7 @@ void rtl8168_raise_clock(struct rtl8168_private *tp, u8 *x)
 {
         *x = *x | Cfg9346_EESK;
         RTL_W8(tp, Cfg9346, *x);
-        udelay(RTL_CLOCK_RATE);
+        fsleep(RTL_CLOCK_RATE);
 }
 
 void rtl8168_lower_clock(struct rtl8168_private *tp, u8 *x)
@@ -207,7 +207,7 @@ void rtl8168_lower_clock(struct rtl8168_private *tp, u8 *x)
 
         *x = *x & ~Cfg9346_EESK;
         RTL_W8(tp, Cfg9346, *x);
-        udelay(RTL_CLOCK_RATE);
+        fsleep(RTL_CLOCK_RATE);
 }
 
 void rtl8168_shift_out_bits(struct rtl8168_private *tp, int data, int count)
@@ -226,7 +226,7 @@ void rtl8168_shift_out_bits(struct rtl8168_private *tp, int data, int count)
                         x &= ~Cfg9346_EEDI;
 
                 RTL_W8(tp, Cfg9346, x);
-                udelay(RTL_CLOCK_RATE);
+                fsleep(RTL_CLOCK_RATE);
                 rtl8168_raise_clock(tp, &x);
                 rtl8168_lower_clock(tp, &x);
                 mask = mask >> 1;
@@ -269,7 +269,7 @@ void rtl8168_stand_by(struct rtl8168_private *tp)
         x = RTL_R8(tp, Cfg9346);
         x &= ~(Cfg9346_EECS | Cfg9346_EESK);
         RTL_W8(tp, Cfg9346, x);
-        udelay(RTL_CLOCK_RATE);
+        fsleep(RTL_CLOCK_RATE);
 
         x |= Cfg9346_EECS;
         RTL_W8(tp, Cfg9346, x);
@@ -280,7 +280,7 @@ void rtl8168_set_eeprom_sel_low(struct rtl8168_private *tp)
         RTL_W8(tp, Cfg9346, Cfg9346_EEM1);
         RTL_W8(tp, Cfg9346, Cfg9346_EEM1 | Cfg9346_EESK);
 
-        udelay(20);
+        fsleep(20);
 
         RTL_W8(tp, Cfg9346, Cfg9346_EEM1);
 }
