@@ -55,6 +55,11 @@ int rtl8168_tool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
         ret = 0;
         switch (my_cmd.cmd) {
         case RTLTOOL_READ_MAC:
+                if ((my_cmd.offset + my_cmd.len) > R8168_REGS_SIZE) {
+                        ret = -EINVAL;
+                        break;
+                }
+
                 if (my_cmd.len==1)
                         my_cmd.data = readb(tp->mmio_addr+my_cmd.offset);
                 else if (my_cmd.len==2)
@@ -72,6 +77,11 @@ int rtl8168_tool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 }
                 break;
         case RTLTOOL_WRITE_MAC:
+                if ((my_cmd.offset + my_cmd.len) > R8168_REGS_SIZE) {
+                        ret = -EINVAL;
+                        break;
+                }
+
                 if (my_cmd.len==1)
                         writeb(my_cmd.data, tp->mmio_addr+my_cmd.offset);
                 else if (my_cmd.len==2)
